@@ -50,8 +50,7 @@ class MainWrapper:
             assert code == 0
         if std:
             return (code, stdout, stderr)
-        else:
-            return code
+        return code
 
 
 cs = MainWrapper()
@@ -64,7 +63,10 @@ def run_codespell(
     """Run codespell."""
     args = tuple(str(arg) for arg in args)
     proc = subprocess.run(
-        ["codespell", "--count", *args], cwd=cwd, capture_output=True, encoding="utf-8"
+        ["codespell", "--count", *args],  # noqa: S603, S607
+        cwd=cwd,
+        capture_output=True,
+        encoding="utf-8",
     )
     count = int(proc.stderr.split("\n")[-2])
     return count
@@ -95,6 +97,9 @@ def test_basic(
     with fname.open("a") as f:
         f.write("this is a test file\n")
     assert cs.main(fname) == 0, "good"
+    with fname.open("a") as f:
+        f.write("var = '\\nDoes not error on newline'\n")
+    assert cs.main(fname) == 0, "with string escape"
     with fname.open("a") as f:
         f.write("abandonned\n")
     assert cs.main(fname) == 1, "bad"
@@ -141,7 +146,7 @@ def test_basic(
     assert isinstance(result, tuple)
     code, stdout, stderr = result
     assert code == 0
-    assert stdout == stderr == ""
+    assert not stdout and not stderr
     assert cs.main(tmp_path) == 0
 
     # empty directory
@@ -172,7 +177,7 @@ def test_bad_glob(
     assert cs.main("--skip", "[[]b-a[]].txt", g) == 0
 
 
-@pytest.mark.skipif(not sys.platform == "linux", reason="Only supported on Linux")
+@pytest.mark.skipif(sys.platform != "linux", reason="Only supported on Linux")
 def test_permission_error(
     tmp_path: Path,
     capsys: pytest.CaptureFixture[str],
@@ -266,7 +271,7 @@ def test_summary(
     assert isinstance(result, tuple)
     code, stdout, stderr = result
     assert code == 0
-    assert stdout == stderr == "", "no output"
+    assert not stdout and not stderr, "no output"
     result = cs.main(fname, "--summary", std=True)
     assert isinstance(result, tuple)
     code, stdout, stderr = result
@@ -375,15 +380,25 @@ def test_encoding(
     assert isinstance(result, tuple)
     code, stdout, stderr = result
     assert code == 0
-    assert stdout == stderr == ""
+    assert not stdout and not stderr
     result = cs.main("-q", "0", fname, std=True, count=False)
     assert isinstance(result, tuple)
     code, stdout, stderr = result
     assert code == 0
-    assert stdout == ""
+    assert not stdout
     assert "WARNING: Binary file" in stderr
 
 
+def test_unknown_encoding_chardet(
+    tmp_path: Path,
+    capsys: pytest.CaptureFixture[str],
+) -> None:
+    """Test opening a file with unknown encoding using chardet"""
+    fname = tmp_path / "tmp"
+    fname.touch()
+    assert cs.main("--hard-encoding-detection", fname) == 0
+
+
 def test_ignore(
     tmp_path: Path,
     capsys: pytest.CaptureFixture[str],
@@ -445,19 +460,33 @@ def test_check_hidden(
     capsys: pytest.CaptureFixture[str],
 ) -> None:
     """Test ignoring of hidden files."""
-    fname = tmp_path / "test.txt"
     # visible file
-    fname.write_text("abandonned\n")
+    #
+    #         tmp_path
+    #         └── test.txt
+    #
+    fname = tmp_path / "test.txt"
+    fname.write_text("erorr\n")
     assert cs.main(fname) == 1
     assert cs.main(tmp_path) == 1
+
     # hidden file
+    #
+    #         tmp_path
+    #         └── .test.txt
+    #
     hidden_file = tmp_path / ".test.txt"
     fname.rename(hidden_file)
     assert cs.main(hidden_file) == 0
     assert cs.main(tmp_path) == 0
     assert cs.main("--check-hidden", hidden_file) == 1
     assert cs.main("--check-hidden", tmp_path) == 1
+
     # hidden file with typo in name
+    #
+    #         tmp_path
+    #         └── .abandonned.txt
+    #
     typo_file = tmp_path / ".abandonned.txt"
     hidden_file.rename(typo_file)
     assert cs.main(typo_file) == 0
@@ -466,16 +495,28 @@ def test_check_hidden(
     assert cs.main("--check-hidden", tmp_path) == 1
     assert cs.main("--check-hidden", "--check-filenames", typo_file) == 2
     assert cs.main("--check-hidden", "--check-filenames", tmp_path) == 2
+
     # hidden directory
+    #
+    #         tmp_path
+    #         ├── .abandonned
+    #         │   ├── .abandonned.txt
+    #         │   └── subdir
+    #         │       └── .abandonned.txt
+    #         └── .abandonned.txt
+    #
     assert cs.main(tmp_path) == 0
     assert cs.main("--check-hidden", tmp_path) == 1
     assert cs.main("--check-hidden", "--check-filenames", tmp_path) == 2
-    hidden_dir = tmp_path / ".abandonned"
-    hidden_dir.mkdir()
-    copyfile(typo_file, hidden_dir / typo_file.name)
+    hidden = tmp_path / ".abandonned"
+    hidden.mkdir()
+    copyfile(typo_file, hidden / typo_file.name)
+    subdir = hidden / "subdir"
+    subdir.mkdir()
+    copyfile(typo_file, subdir / typo_file.name)
     assert cs.main(tmp_path) == 0
-    assert cs.main("--check-hidden", tmp_path) == 2
-    assert cs.main("--check-hidden", "--check-filenames", tmp_path) == 5
+    assert cs.main("--check-hidden", tmp_path) == 3
+    assert cs.main("--check-hidden", "--check-filenames", tmp_path) == 8
     # check again with a relative path
     try:
         rel = op.relpath(tmp_path)
@@ -484,20 +525,28 @@ def test_check_hidden(
         pass
     else:
         assert cs.main(rel) == 0
-        assert cs.main("--check-hidden", rel) == 2
-        assert cs.main("--check-hidden", "--check-filenames", rel) == 5
+        assert cs.main("--check-hidden", rel) == 3
+        assert cs.main("--check-hidden", "--check-filenames", rel) == 8
+
     # hidden subdirectory
-    assert cs.main(tmp_path) == 0
-    assert cs.main("--check-hidden", tmp_path) == 2
-    assert cs.main("--check-hidden", "--check-filenames", tmp_path) == 5
+    #
+    #         tmp_path
+    #         ├── .abandonned
+    #         │   ├── .abandonned.txt
+    #         │   └── subdir
+    #         │       └── .abandonned.txt
+    #         ├── .abandonned.txt
+    #         └── subdir
+    #             └── .abandonned
+    #                 └── .abandonned.txt
     subdir = tmp_path / "subdir"
     subdir.mkdir()
-    hidden_subdir = subdir / ".abandonned"
-    hidden_subdir.mkdir()
-    copyfile(typo_file, hidden_subdir / typo_file.name)
+    hidden = subdir / ".abandonned"
+    hidden.mkdir()
+    copyfile(typo_file, hidden / typo_file.name)
     assert cs.main(tmp_path) == 0
-    assert cs.main("--check-hidden", tmp_path) == 3
-    assert cs.main("--check-hidden", "--check-filenames", tmp_path) == 8
+    assert cs.main("--check-hidden", tmp_path) == 4
+    assert cs.main("--check-hidden", "--check-filenames", tmp_path) == 11
 
 
 def test_case_handling(
